@@ -4,19 +4,18 @@ Created on 10.10.2011
 @author: xaralis
 '''
 
-from django.template.loaders.app_directories import Loader
+from django.template.loader import render_to_string
 import ella_newman as newman
 
 from informant.models import Newsletter, Recipient
 
 class NewsletterAdmin(newman.NewmanModelAdmin):
-    list_display = ('subject', 'date', 'sent', 'approved', 'preview_url',)
+    list_display = ('subject', 'date', 'testing_emails', 'sent', 'approved', 'preview_url',)
     ordering = ('-date',)
 
     def formfield_for_dbfield(self, db_field, **kwargs):
         if db_field.name == 'content':
-            l = Loader()
-            kwargs['initial'] = l.load_template_source('newsletters/mail/body/iw-newsletter.html')[0]
+            kwargs['initial'] = render_to_string('informant/mail/newsletter.html')
         return super(NewsletterAdmin, self).formfield_for_dbfield(db_field, **kwargs)
 
 class RecipientAdmin(newman.NewmanModelAdmin):
